# lshid

Like lsusb, but for HID devices.

```
$ lshid
Device /dev/hidraw0: ID 08bb:2902 Burr-Brown from TI               USB Audio CODEC
Device /dev/hidraw5: ID 046d:405f Logitech Candy
Device /dev/hidraw4: ID 046d:4079 Logitech G Pro
Device /dev/hidraw3: ID 046d:c53a Logitech USB Receiver
Device /dev/hidraw2: ID 046d:c53a Logitech USB Receiver
Device /dev/hidraw1: ID 046d:c53a Logitech USB Receiver
Device /dev/hidraw13: ID 046d:c33c Logitech G513 Carbon Tactile
Device /dev/hidraw12: ID 046d:c33c Logitech G513 Carbon Tactile
```
